@@ -9,7 +9,7 @@ station <- function(lon = NULL, lat = NULL, pch = 24, col = "blue",
     if (missing(lon) || missing(lat))
     {
         ## read in the station longitude-latitude data and do a conversion.
-        data(WTdiff)
+        data(WTdiff, package="sspline")
         lon <- WTdiff$lon*pi/180; lat <- WTdiff$lat*pi/180
     }
     else if (length(lon) != length(lat))
